==> enterprisemodules-wls_config-3.2.2.tar.gz: enterprisemodules-wls_config-3.2.2/lib/puppet/type/wls_workmanager.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  Type.newtype(:wls_workmanager) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-EOD
    This resource allows you to manage workmanagers in an WebLogic domain.

    Here is an example on how you should use this:

        wls_workmanager { 'WorkManagerConstraints':
          ensure                => 'present',
          capacity              => 'CapacityConstraint',
          maxthreadsconstraint  => 'MaxThreadsConstraint',
          minthreadsconstraint  => 'MinThreadsConstraint',
          fairsharerequestclass => 'FairShareReqClass',
          stuckthreads          => '0',
          target                => ['WebCluster'],
          targettype            => ['Cluster'],
        }

    In this example you are managing a work manager in the default domain. When you want to
    manage a work manager in a specific domain, you can use:

        wls_workmanager { 'my_domain/WorkManagerConstraints':
          ensure                => 'present',
          capacity              => 'CapacityConstraint',
          maxthreadsconstraint  => 'MaxThreadsConstraint',
          minthreadsconstraint  => 'MinThreadsConstraint',
          fairsharerequestclass => 'FairShareReqClass',
          stuckthreads          => '0',
          target                => ['WebCluster'],
          targettype            => ['Cluster'],
        }

    EOD

    bean_path('/SelfTuning/%{domain_name}/WorkManagers')
    bean_type('WorkManager')

    ensurable
    parameter :workmanager_name
    parameter :domain
    parameter :name
    parameter :timeout

    property :stuckthreads
    property :target
    property :targettype
    property :minthreadsconstraint
    property :maxthreadsconstraint
    property :fairsharerequestclass
    property :capacity
    extraproperties do
      property :context_request_class
      property :deployment_order
      property :ignore_stuck_threads
      property :min_threads_constraint
      property :notes
      property :work_manager_shutdown_trigger
      property :fair_share_request_class
      property :max_threads_constraint
      property :response_time_request_class
      #
      # Weblogic 12.2.1 new properties
      #
      property :application_scope
      property :tags
    end

    add_title_attributes(:workmanager_name)
  end
end

==> enterprisemodules-wls_config-3.14.4.tar.gz: enterprisemodules-wls_config-3.14.4/lib/puppet/type/wls_workmanager.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  Type.newtype(:wls_workmanager) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-DESC
    This resource allows you to manage workmanagers in an WebLogic domain.

    Here is an example on how you should use this:

        wls_workmanager { 'WorkManagerConstraints':
          ensure                => 'present',
          capacity              => 'CapacityConstraint',
          maxthreadsconstraint  => 'MaxThreadsConstraint',
          minthreadsconstraint  => 'MinThreadsConstraint',
          fairsharerequestclass => 'FairShareReqClass',
          stuckthreads          => '0',
          target                => ['WebCluster'],
          targettype            => ['Cluster'],
        }

    In this example you are managing a work manager in the default domain. When you want to
    manage a work manager in a specific domain, you can use:

        wls_workmanager { 'my_domain/WorkManagerConstraints':
          ensure                => 'present',
          capacity              => 'CapacityConstraint',
          maxthreadsconstraint  => 'MaxThreadsConstraint',
          minthreadsconstraint  => 'MinThreadsConstraint',
          fairsharerequestclass => 'FairShareReqClass',
          stuckthreads          => '0',
          target                => ['WebCluster'],
          targettype            => ['Cluster'],
        }

    DESC

    bean_path('/SelfTuning/%<domain_name>s/WorkManagers')
    bean_type('WorkManager')

    ensurable
    parameter :workmanager_name
    parameter :domain
    parameter :name
    parameter :timeout

    property :stuckthreads
    property :target
    property :targettype
    property :minthreadsconstraint
    property :maxthreadsconstraint
    property :fairsharerequestclass
    property :capacity
    extraproperties do
      property :context_request_class
      property :deployment_order
      property :ignore_stuck_threads
      property :min_threads_constraint
      property :notes
      property :work_manager_shutdown_trigger
      property :fair_share_request_class
      property :max_threads_constraint
      property :response_time_request_class
      #
      # Weblogic 12.2.1 new properties
      #
      property :application_scope
      property :tags
    end

    add_title_attributes(:workmanager_name)
  end
end
